local L = AceLibrary("AceLocale-2.2"):new("NinjutFu")
local dewdrop = AceLibrary("Dewdrop-2.0")

local SM = LibStub:GetLibrary("LibSharedMedia-2.0", true)
if SM then
	SM:Register("sound", "Flute", [[Sound\Spells\FluteRun.wav]])
end

function NinjutFu:OnMenuRequest(level, value, inTooltip, valueN_1, valueN_2, valueN_3, valueN_4)
	if level == 1 then
		dewdrop:AddLine(
			'text', L["Options"],
			'tooltipTitle', L["Options"],
			'tooltipText', L["OptionsDesc"],
			'hasArrow', true,
			'value', "options"
		)
		dewdrop:AddLine()
	elseif level == 2 then
		if value == "options" then
			dewdrop:AddLine(
				'text', L["buyFlash"],
				'tooltipTitle', L["buyFlash"],
				'tooltipText', L["buyFlashDesc"],
				'checked', NinjutFu.db.profile.buyFlash,
				'func', function() NinjutFu.db.profile.buyFlash = not NinjutFu.db.profile.buyFlash end,
				'hasArrow', true,
				'hasSlider', true,
				'sliderMax', 100,
				'sliderValue', NinjutFu.db.profile.threshCount,
				'sliderStep', 5,
				'sliderFunc', function(v) NinjutFu.db.profile.threshCount = v end
			)
			dewdrop:AddLine(
				'text', L["warnPoisonExpire"],
				'tooltipTitle', L["warnPoisonExpire"],
				'tooltipText', L["warnPoisonExpireDesc"],
				'checked', NinjutFu.db.profile.warnPoisonExpire,
				'func', function() NinjutFu.db.profile.warnPoisonExpire = not NinjutFu.db.profile.warnPoisonExpire; NinjutFu:PoisonWatchChanged() end,
				'hasArrow', true,
				'value', "warnPoisonExpire"
			)
			dewdrop:AddLine()
			dewdrop:AddLine(
				'text', L["Text Options"],
				'tooltipTitle', L["Text Options"],
				'tooltipText', L["TextOptsDesc"],
				'isTitle', true
			)
			dewdrop:AddLine(
				'text', L["Show Flash Powder"],
				'tooltipTitle', L["Show Flash Powder"],
				'tooltipText', L["ShowFlashDesc"],
				'checked', NinjutFu.db.profile.showFlash,
				'func', function() NinjutFu.db.profile.showFlash = not NinjutFu.db.profile.showFlash; NinjutFu:UpdateText() end
			)
			dewdrop:AddLine(
				'text', L["Show Thistle Tea"],
				'tooltipTitle', L["Show Thistle Tea"],
				'tooltipText', L["ShowTeaDesc"],
				'checked', NinjutFu.db.profile.showTea,
				'func', function() NinjutFu.db.profile.showTea = not NinjutFu.db.profile.showTea; NinjutFu:UpdateText() end
			)
			dewdrop:AddLine(
				'text', L["Compact Mode"],
				'tooltipTitle', L["Compact Mode"],
				'tooltipText', L["CompactModeDesc"],
				'checked', NinjutFu.db.profile.compactMode,
				'func', function() NinjutFu.db.profile.compactMode = not NinjutFu.db.profile.compactMode; NinjutFu:UpdateText() end
			)
			dewdrop:AddLine()
			dewdrop:AddLine(
				'text', L["Tooltip Options"],
				'tooltipTitle', L["Tooltip Options"],
				'tooltipText', L["TooltipOptsDesc"],
				'isTitle', true
			)
			dewdrop:AddLine(
				'text', L["Show Titles"],
				'tooltipTitle', L["Show Titles"],
				'tooltipText', L["ShowTitlesDesc"],
				'checked', NinjutFu.db.profile.showTipTitles,
				'func', function() NinjutFu.db.profile.showTipTitles = not NinjutFu.db.profile.showTipTitles; NinjutFu:UpdateTooltip() end
			)
			for category in NinjutFu:IterItemCategories() do
				dewdrop:AddLine(
					'text', string.format(L["Show %s"], L[category]),
					'tooltipTitle', string.format(L["Show %s"], L[category]),
					'tooltipText', string.format(L["ShowCatDesc"], L[category]),
					'checked', not string.find(NinjutFu.db.profile.tooltipSkipCategories, category .. ":"),
					'func', function()
							if string.find(NinjutFu.db.profile.tooltipSkipCategories, category .. ":") == nil then
								NinjutFu.db.profile.tooltipSkipCategories = NinjutFu.db.profile.tooltipSkipCategories .. category .. ":"
							else
								NinjutFu.db.profile.tooltipSkipCategories = string.gsub(NinjutFu.db.profile.tooltipSkipCategories, category .. ":", "")
							end
						end
				)
			end
		end
	elseif level == 3 then
		if value == "warnPoisonExpire" then
			if not SM then
				-- Check if SharedMedia have been loaded
				SM = LibStub:GetLibrary("LibSharedMedia-2.0", true)
				if SM then
					SM:Register("sound", "Flute", [[Sound\Spells\FluteRun.wav]])
				end
			end
			dewdrop:AddLine(
				'text', L["Play Sound"],
				'tooltipTitle', L["Play Sound"],
				'tooltipText', L["PlaySoundDesc"],
				'checked', NinjutFu.db.profile.warnPlaySound,
				'func', function() NinjutFu.db.profile.warnPlaySound = not NinjutFu.db.profile.warnPlaySound end,
				'hasArrow', SM and NinjutFu.db.profile.warnPlaySound,
				'value', "warnPlaySound"
			)
			if not SM and NinjutFu.db.profile.warnSound ~= [[Sound\Spells\FluteRun.wav]] then
				dewdrop:AddLine(
					'text', L["Reset Sound"],
					'tooltipTitle', L["Reset Sound"],
					'tooltipText', L["ResetSoundDesc"],
					'func', function() NinjutFu.db.profile.warnSound = [[Sound\Spells\FluteRun.wav]] end
				)
			end
		end
	elseif level == 4 then
		if value == "warnPlaySound" then
			for k, v in ipairs(SM:List("sound")) do
				dewdrop:AddLine(
					'text', v,
					'tooltipTitle', v,
					'tooltipText', L["Ctrl-Click to listen"],
					'checked', NinjutFu.db.profile.warnSound == SM:Fetch("sound", v),
					'func', function()
						PlaySoundFile(SM:Fetch("sound", v))
						if not IsControlKeyDown() then
							NinjutFu.db.profile.warnSound = SM:Fetch("sound", v)
						end
					end
				)
			end
		end
	end
end
